import { jsx as _jsx } from "react/jsx-runtime";
import { Chart as ChartJS, CategoryScale, LinearScale, PointElement, LineElement, Title, Tooltip, } from 'chart.js';
import { Line } from 'react-chartjs-2';
import tokens from '@contentful/f36-tokens';
import { parseRemToPxInt } from '../../../helpers/ParseStylingToken/ParseStylingToken';
import { styles } from './LineChart.styles';
const ACCESSIBILITY_LABEL = 'Analytics line chart';
const defaultFontSize = parseRemToPxInt(tokens.fontSizeS);
const Y_AXIS_SCALAR = 1.2;
const LineChart = (props) => {
    const { dataValues, xAxisLabels, tooltipMetricLabel, accessibilityLabel } = props;
    ChartJS.register(CategoryScale, LinearScale, PointElement, LineElement, Title, Tooltip);
    ChartJS.defaults.font.size = defaultFontSize;
    ChartJS.defaults.font.family = tokens.fontStackPrimary;
    ChartJS.defaults.font.weight = tokens.fontWeightMedium.toString();
    ChartJS.defaults.borderColor = tokens.gray200;
    ChartJS.defaults.datasets.line.borderColor = tokens.colorPrimary;
    const data = {
        labels: xAxisLabels,
        datasets: [
            {
                data: dataValues,
            },
        ],
    };
    const options = {
        responsive: true,
        scales: {
            y: {
                beginAtZero: true,
                suggestedMax: Math.max(...dataValues) * Y_AXIS_SCALAR,
                ticks: {
                    precision: 0,
                },
            },
        },
        plugins: {
            tooltip: {
                backgroundColor: tokens.gray900,
                bodyColor: tokens.colorWhite,
                padding: parseRemToPxInt(tokens.spacingXs),
                titleMarginBottom: parseRemToPxInt(tokens.spacing2Xs),
                titleFont: {
                    size: defaultFontSize,
                },
                bodyFont: {
                    size: defaultFontSize,
                    weight: '700',
                },
                displayColors: false,
                callbacks: {
                    beforeBody: () => tooltipMetricLabel,
                },
            },
        },
    };
    const chartProps = {
        'aria-label': accessibilityLabel,
    };
    return (_jsx("div", { className: styles.root, children: _jsx(Line, { data: data, options: options, fallbackContent: accessibilityLabel, ...chartProps }) }));
};
LineChart.defaultProps = {
    accessibilityLabel: ACCESSIBILITY_LABEL,
};
export default LineChart;
//# sourceMappingURL=LineChart.js.map